import{S as r,i as f,s as _,U as u,f as m,b as c,t as o,c as b,P as h,Q as g,R as p,v as w,w as d,e as k}from"./index.b05fc228.js";function v(a){let s,n;const i=a[2].default,t=u(i,a,a[1],null);return{c(){s=m("span"),t&&t.c(),c(s,"class","text-gray-600 text-[0.855rem] mb-2 block dark:text-gray-200 relative z-40"),o(s,"sr-only",!a[0]),o(s,"h-0",!a[0]),o(s,"!m-0",!a[0])},m(e,l){b(e,s,l),t&&t.m(s,null),n=!0},p(e,[l]){t&&t.p&&(!n||l&2)&&h(t,i,e,e[1],n?p(i,e[1],l,null):g(e[1]),null),l&1&&o(s,"sr-only",!e[0]),l&1&&o(s,"h-0",!e[0]),l&1&&o(s,"!m-0",!e[0])},i(e){n||(w(t,e),n=!0)},o(e){d(t,e),n=!1},d(e){e&&k(s),t&&t.d(e)}}}function B(a,s,n){let{$$slots:i={},$$scope:t}=s,{show_label:e=!0}=s;return a.$$set=l=>{"show_label"in l&&n(0,e=l.show_label),"$$scope"in l&&n(1,t=l.$$scope)},[e,t,i]}class q extends r{constructor(s){super(),f(this,s,B,v,_,{show_label:0})}}export{q as B};
