import{S as r,i as u,s as _,U as f,f as c,b as m,c as p,P as d,Q as v,R as y,v as b,w as g,e as G}from"./index.b05fc228.js";function h(a){let s,l;const i=a[3].default,t=f(i,a,a[2],null);return{c(){s=c("div"),t&&t.c(),m(s,"class","svelte-n6dnoo")},m(e,n){p(e,s,n),t&&t.m(s,null),l=!0},p(e,[n]){t&&t.p&&(!l||n&4)&&d(t,i,e,e[2],l?y(i,e[2],n,null):v(e[2]),null)},i(e){l||(b(t,e),l=!0)},o(e){g(t,e),l=!1},d(e){e&&G(s),t&&t.d(e)}}}function C(a,s,l){let{$$slots:i={},$$scope:t}=s,{parent:e=null}=s,{style:n={}}=s;return typeof n.mobile_collapse!="boolean"&&(n.mobile_collapse=!0),a.$$set=o=>{"parent"in o&&l(1,e=o.parent),"style"in o&&l(0,n=o.style),"$$scope"in o&&l(2,t=o.$$scope)},[n,e,t,i]}class S extends r{constructor(s){super(),u(this,s,C,h,_,{parent:1,style:0})}}var w=S;const P=["static"];export{w as Component,P as modes};
