import{S as i,i as u,s as _,q as m,u as p,v as c,w as f,x as d,U as g,P as b,Q as $,R as y}from"./index.b05fc228.js";import{B}from"./Block.69223ac1.js";import"./styles.d87a390f.js";function h(l){let t;const n=l[2].default,e=g(n,l,l[3],null);return{c(){e&&e.c()},m(s,o){e&&e.m(s,o),t=!0},p(s,o){e&&e.p&&(!t||o&8)&&b(e,n,s,s[3],t?y(n,s[3],o,null):$(s[3]),null)},i(s){t||(c(e,s),t=!0)},o(s){f(e,s),t=!1},d(s){e&&e.d(s)}}}function k(l){let t,n;return t=new B({props:{$$slots:{default:[h]},$$scope:{ctx:l}}}),{c(){m(t.$$.fragment)},m(e,s){p(t,e,s),n=!0},p(e,[s]){const o={};s&8&&(o.$$scope={dirty:s,ctx:e}),t.$set(o)},i(e){n||(c(t.$$.fragment,e),n=!0)},o(e){f(t.$$.fragment,e),n=!1},d(e){d(t,e)}}}function q(l,t,n){let{$$slots:e={},$$scope:s}=t,{parent:o=null}=t,{style:r={}}=t;return typeof r.mobile_collapse!="boolean"&&(r.mobile_collapse=!0),l.$$set=a=>{"parent"in a&&n(1,o=a.parent),"style"in a&&n(0,r=a.style),"$$scope"in a&&n(3,s=a.$$scope)},[r,o,e,s]}class w extends i{constructor(t){super(),u(this,t,q,k,_,{parent:1,style:0})}}var P=w;const Q=["static"];export{P as Component,Q as modes};
