import{S as p,i as $,s as h,q as c,u as m,v as i,w as f,x as d,L as C,M as b,U as k,m as w,c as S,N as q,O as v,P as j,Q as F,R as L,e as M,F as N}from"./index.b05fc228.js";import{C as O}from"./CarouselItem.svelte_svelte_type_style_lang.d9530415.js";function P(n){let t,o,s;const l=[n[1]];let r={};for(let e=0;e<l.length;e+=1)r=C(r,l[e]);t=new b({props:r});const _=n[2].default,a=k(_,n,n[4],null);return{c(){c(t.$$.fragment),o=w(),a&&a.c()},m(e,u){m(t,e,u),S(e,o,u),a&&a.m(e,u),s=!0},p(e,u){const g=u&2?q(l,[v(e[1])]):{};t.$set(g),a&&a.p&&(!s||u&16)&&j(a,_,e,e[4],s?L(_,e[4],u,null):F(e[4]),null)},i(e){s||(i(t.$$.fragment,e),i(a,e),s=!0)},o(e){f(t.$$.fragment,e),f(a,e),s=!1},d(e){d(t,e),e&&M(o),a&&a.d(e)}}}function Q(n){let t,o;return t=new O({props:{elem_id:n[0],$$slots:{default:[P]},$$scope:{ctx:n}}}),t.$on("change",n[3]),{c(){c(t.$$.fragment)},m(s,l){m(t,s,l),o=!0},p(s,[l]){const r={};l&1&&(r.elem_id=s[0]),l&18&&(r.$$scope={dirty:l,ctx:s}),t.$set(r)},i(s){o||(i(t.$$.fragment,s),o=!0)},o(s){f(t.$$.fragment,s),o=!1},d(s){d(t,s)}}}function R(n,t,o){let{$$slots:s={},$$scope:l}=t,{elem_id:r=""}=t,{loading_status:_}=t;function a(e){N.call(this,n,e)}return n.$$set=e=>{"elem_id"in e&&o(0,r=e.elem_id),"loading_status"in e&&o(1,_=e.loading_status),"$$scope"in e&&o(4,l=e.$$scope)},[r,_,s,a,l]}class T extends p{constructor(t){super(),$(this,t,R,Q,h,{elem_id:0,loading_status:1})}}var A=T;const B=["static"];export{A as Component,B as modes};
