import{S as u,i as d,s as m,f as h,b as c,W as v,c as g,n as o,e as w,A as _,q as b,u as k,v as y,w as M,x as q,F as x}from"./index.b05fc228.js";function C(a){let e;return{c(){e=h("div"),c(e,"id",a[0]),c(e,"class","output-markdown prose"),v(e,"max-width","100%")},m(n,t){g(n,e,t),e.innerHTML=a[1]},p(n,[t]){t&2&&(e.innerHTML=n[1]),t&1&&c(e,"id",n[0])},i:o,o,d(n){n&&w(e)}}}function H(a,e,n){let{elem_id:t=""}=e,{value:i}=e;const s=_();return a.$$set=l=>{"elem_id"in l&&n(0,t=l.elem_id),"value"in l&&n(1,i=l.value)},a.$$.update=()=>{a.$$.dirty&2&&s("change")},[t,i]}class L extends u{constructor(e){super(),d(this,e,H,C,m,{elem_id:0,value:1})}}function S(a){let e,n;return e=new L({props:{value:a[0]}}),e.$on("change",a[3]),{c(){b(e.$$.fragment)},m(t,i){k(e,t,i),n=!0},p(t,[i]){const s={};i&1&&(s.value=t[0]),e.$set(s)},i(t){n||(y(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){q(e,t)}}}function T(a,e,n){let{label:t}=e,{elem_id:i=""}=e,{value:s=""}=e;const l=_();function f(r){x.call(this,a,r)}return a.$$set=r=>{"label"in r&&n(1,t=r.label),"elem_id"in r&&n(2,i=r.elem_id),"value"in r&&n(0,s=r.value)},a.$$.update=()=>{a.$$.dirty&2&&l("change")},[s,t,i,f]}class p extends u{constructor(e){super(),d(this,e,T,S,m,{label:1,elem_id:2,value:0})}}var D=p;const E=["static"];export{D as Component,E as modes};
