import{S as c,i as _,s as f,q as m,u as d,v as r,w as i,x as p,U as $,P as g,Q as b,R as h,F as T}from"./index.b05fc228.js";import{T as q}from"./Tabs.0bad1099.js";function v(a){let t;const n=a[1].default,e=$(n,a,a[3],null);return{c(){e&&e.c()},m(s,o){e&&e.m(s,o),t=!0},p(s,o){e&&e.p&&(!t||o&8)&&g(e,n,s,s[3],t?h(n,s[3],o,null):b(s[3]),null)},i(s){t||(r(e,s),t=!0)},o(s){i(e,s),t=!1},d(s){e&&e.d(s)}}}function w(a){let t,n;return t=new q({props:{$$slots:{default:[v]},$$scope:{ctx:a}}}),t.$on("change",a[2]),{c(){m(t.$$.fragment)},m(e,s){d(t,e,s),n=!0},p(e,[s]){const o={};s&8&&(o.$$scope={dirty:s,ctx:e}),t.$set(o)},i(e){n||(r(t.$$.fragment,e),n=!0)},o(e){i(t.$$.fragment,e),n=!1},d(e){p(t,e)}}}function C(a,t,n){let{$$slots:e={},$$scope:s}=t,{elem_id:o=""}=t;function u(l){T.call(this,a,l)}return a.$$set=l=>{"elem_id"in l&&n(0,o=l.elem_id),"$$scope"in l&&n(3,s=l.$$scope)},[o,e,u,s]}class S extends c{constructor(t){super(),_(this,t,C,w,f,{elem_id:0})}}var Q=S;const R=["static"];export{Q as Component,R as modes};
