<!DOCTYPE html>
<html
	lang="en"
	style="
		margin: 0;
		padding: 0;
		display: flex;
		flex-direction: column;
		flex-grow: 1;
		height: 100%;
	"
>
	<head>
		<base target="_blank" />
		<meta charset="utf-8" />
		<meta
			name="viewport"
			content="width=device-width, initial-scale=1, shrink-to-fit=no"
		/>

		
		<meta property="og:url" content="https://gradio.app/" />
		<meta property="og:type" content="website" />
		<meta property="og:image" content="{{ config['thumbnail'] or '' }}" />
		<meta property="og:title" content="{{ config['title'] or '' }}" />
		<meta
			property="og:description"
			content="{{ config['simple_description'] or '' }}"
		/>
		<meta name="twitter:card" content="summary_large_image" />
		<meta name="twitter:creator" content="@teamGradio" />
		<meta name="twitter:title" content="{{ config['title'] or '' }}" />
		<meta
			name="twitter:description"
			content="{{ config['simple_description'] or '' }}"
		/>
		<meta name="twitter:image" content="{{ config['thumbnail'] or '' }}" />

		<script>
			window.dataLayer = window.dataLayer || [];
			function gtag() {
				dataLayer.push(arguments);
			}
			gtag("js", new Date());
			gtag("config", "UA-156449732-1");
			window.gradio_mode = "app";
		</script>

		<script>window.gradio_config = {{ config | tojson }};</script>

		<link rel="preconnect" href="https://fonts.googleapis.com" />
		<link
			rel="preconnect"
			href="https://fonts.gstatic.com"
			crossorigin="anonymous"
		/>
		<link
			href="https://fonts.googleapis.com/css2?family=IBM+Plex+Mono:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;1,100;1,200;1,300;1,400;1,500;1,600&family=IBM+Plex+Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;1,100;1,200;1,300;1,400;1,500;1,600;1,700&family=IBM+Plex+Serif:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;1,100;1,200;1,300;1,400;1,500;1,600;1,700&display=swap"
			rel="stylesheet"
		/>
		<script src="https://cdnjs.cloudflare.com/ajax/libs/iframe-resizer/4.3.1/iframeResizer.contentWindow.min.js"></script>
		<script type="module" crossorigin src="https://gradio.s3-us-west-2.amazonaws.com/3.0b6/assets/index.b05fc228.js"></script>
		<link rel="stylesheet" href="https://gradio.s3-us-west-2.amazonaws.com/3.0b6/assets/index.4b0ec74e.css">
	</head>

	<body
		style="
			margin: 0;
			padding: 0;
			display: flex;
			flex-direction: column;
			flex-grow: 1;
		"
	>
		<div
			id="root"
			style="display: flex; flex-direction: column; flex-grow: 1"
		></div>
	</body>
</html>
