import{S as _,i as m,s as c,U as g,f as p,b as r,t as i,c as b,P as w,Q as h,R as d,v as q,w as v,e as R}from"./index.b05fc228.js";import{c as u}from"./styles.d87a390f.js";function C(t){let l,f,o;const n=t[3].default,a=g(n,t,t[2],null);return{c(){l=p("div"),a&&a.c(),r(l,"class",f="flex md:flex-row gr-gap gr-form-gap row w-full "+u(t[0])),i(l,"mobile-row",t[0].mobile_collapse===!1),i(l,"unequal-height",t[0].equal_height===!1),i(l,"flex-col",t[0].mobile_collapse)},m(e,s){b(e,l,s),a&&a.m(l,null),o=!0},p(e,[s]){a&&a.p&&(!o||s&4)&&w(a,n,e,e[2],o?d(n,e[2],s,null):h(e[2]),null),(!o||s&1&&f!==(f="flex md:flex-row gr-gap gr-form-gap row w-full "+u(e[0])))&&r(l,"class",f),s&1&&i(l,"mobile-row",e[0].mobile_collapse===!1),s&1&&i(l,"unequal-height",e[0].equal_height===!1),s&1&&i(l,"flex-col",e[0].mobile_collapse)},i(e){o||(q(a,e),o=!0)},o(e){v(a,e),o=!1},d(e){e&&R(l),a&&a.d(e)}}}function S(t,l,f){let{$$slots:o={},$$scope:n}=l,{parent:a=null}=l,{style:e={}}=l;return typeof e.mobile_collapse!="boolean"&&(e.mobile_collapse=!0),t.$$set=s=>{"parent"in s&&f(1,a=s.parent),"style"in s&&f(0,e=s.style),"$$scope"in s&&f(2,n=s.$$scope)},[e,a,n,o]}class y extends _{constructor(l){super(),m(this,l,S,C,c,{parent:1,style:0})}}var U=y;const j=["static"];export{U as Component,j as modes};
