import{S as O,i as P,s as k,f as Q,b as a,t as f,c as K,P as R,Q as T,R as U,v as N,w as S,e as q,k as Y,T as j,U as z}from"./index.b05fc228.js";import{c as C}from"./styles.d87a390f.js";function b(n){let e,i,r;const s=n[14].default,o=z(s,n,n[13],null);return{c(){e=Q(n[10]),o&&o.c(),a(e,"data-testid",n[6]),a(e,"id",n[1]),a(e,"class",i="w-full overflow-hidden "+n[9][n[2]]+" "+n[9][n[3]]+" "+n[8]+C(n[0],"container")),f(e,"gr-panel",n[4]),f(e,"form",n[5]),f(e,"gr-box-unrounded",n[5]),f(e,"gr-box",!n[5]),f(e,"!p-0",n[7]),f(e,"!m-0",n[7]),f(e,"!border-0",n[7]),f(e,"!shadow-none",n[7]),f(e,"overflow-visible",n[7])},m(l,t){K(l,e,t),o&&o.m(e,null),r=!0},p(l,t){o&&o.p&&(!r||t&8192)&&R(o,s,l,l[13],r?U(s,l[13],t,null):T(l[13]),null),(!r||t&64)&&a(e,"data-testid",l[6]),(!r||t&2)&&a(e,"id",l[1]),(!r||t&269&&i!==(i="w-full overflow-hidden "+l[9][l[2]]+" "+l[9][l[3]]+" "+l[8]+C(l[0],"container")))&&a(e,"class",i),t&285&&f(e,"gr-panel",l[4]),t&301&&f(e,"form",l[5]),t&301&&f(e,"gr-box-unrounded",l[5]),t&301&&f(e,"gr-box",!l[5]),t&397&&f(e,"!p-0",l[7]),t&397&&f(e,"!m-0",l[7]),t&397&&f(e,"!border-0",l[7]),t&397&&f(e,"!shadow-none",l[7]),t&397&&f(e,"overflow-visible",l[7])},i(l){r||(N(o,l),r=!0)},o(l){S(o,l),r=!1},d(l){l&&q(e),o&&o.d(l)}}}function A(n){let e=n[10],i,r,s=n[10]&&b(n);return{c(){s&&s.c(),i=Y()},m(o,l){s&&s.m(o,l),K(o,i,l),r=!0},p(o,[l]){o[10]?e?k(e,o[10])?(s.d(1),s=b(o),s.c(),s.m(i.parentNode,i)):s.p(o,l):(s=b(o),s.c(),s.m(i.parentNode,i)):e&&(s.d(1),s=null),e=o[10]},i(o){r||(N(s),r=!0)},o(o){S(s),r=!1},d(o){o&&q(i),s&&s.d(o)}}}function D(n,e,i){let r,s,{$$slots:o={},$$scope:l}=e,{style:t={}}=e,{elem_id:w=""}=e,{variant:v="solid"}=e,{color:h="grey"}=e,{padding:c=!0}=e,{form_position:u=void 0}=e,{type:m="normal"}=e,{test_id:y=void 0}=e,{disable:B=!1}=e;const E={dashed:"border-dashed border border-gray-300",solid:"border-solid border",grey:"border-gray-200",green:"border-green-400",none:"!border-0"},_={column:{first:"rounded-t-lg",last:"rounded-b-lg",mid:"",single:"rounded-lg"},row:{first:"rounded-t-lg md:rounded-t-none md:rounded-l-lg ",last:"rounded-b-lg md:rounded-b-none md:rounded-r-lg",mid:"",single:"rounded-lg"}};let L=m==="fieldset"?"fieldset":"div";const g=j("BLOCK_KEY");return n.$$set=d=>{"style"in d&&i(0,t=d.style),"elem_id"in d&&i(1,w=d.elem_id),"variant"in d&&i(2,v=d.variant),"color"in d&&i(3,h=d.color),"padding"in d&&i(4,c=d.padding),"form_position"in d&&i(5,u=d.form_position),"type"in d&&i(11,m=d.type),"test_id"in d&&i(6,y=d.test_id),"disable"in d&&i(7,B=d.disable),"$$scope"in d&&i(13,l=d.$$scope)},n.$$.update=()=>{n.$$.dirty&4128&&i(8,s=u?_==null?void 0:_[r||"column"][u]:"")},i(12,r=g==="column"||g=="row"?g:"column"),[t,w,v,h,c,u,y,B,s,E,L,m,r,l,o]}class H extends O{constructor(e){super(),P(this,e,D,A,k,{style:0,elem_id:1,variant:2,color:3,padding:4,form_position:5,type:11,test_id:6,disable:7})}}export{H as B};
