import{S as g,i as c,s as d,U as v,f as b,b as u,t as r,c as p,P as C,Q as w,R as h,v as S,w as q,e as y}from"./index.b05fc228.js";import{c as m}from"./styles.d87a390f.js";function P(n){let e,s,i;const o=n[5].default,a=v(o,n,n[4],null);return{c(){e=b("div"),a&&a.c(),u(e,"id",n[0]),u(e,"class",s="flex flex-col gr-gap gr-form-gap relative col w-full "+m(n[2])),r(e,"bg-gray-50",n[1]==="panel"),r(e,"p-2",n[1]==="panel"),r(e,"rounded-lg",n[1]==="panel")},m(l,t){p(l,e,t),a&&a.m(e,null),i=!0},p(l,[t]){a&&a.p&&(!i||t&16)&&C(a,o,l,l[4],i?h(o,l[4],t,null):w(l[4]),null),(!i||t&1)&&u(e,"id",l[0]),(!i||t&4&&s!==(s="flex flex-col gr-gap gr-form-gap relative col w-full "+m(l[2])))&&u(e,"class",s),t&6&&r(e,"bg-gray-50",l[1]==="panel"),t&6&&r(e,"p-2",l[1]==="panel"),t&6&&r(e,"rounded-lg",l[1]==="panel")},i(l){i||(S(a,l),i=!0)},o(l){q(a,l),i=!1},d(l){l&&y(e),a&&a.d(l)}}}function Q(n,e,s){let{$$slots:i={},$$scope:o}=e,{elem_id:a=""}=e,{variant:l="default"}=e,{parent:t=null}=e,{style:_={}}=e;return n.$$set=f=>{"elem_id"in f&&s(0,a=f.elem_id),"variant"in f&&s(1,l=f.variant),"parent"in f&&s(3,t=f.parent),"style"in f&&s(2,_=f.style),"$$scope"in f&&s(4,o=f.$$scope)},[a,l,_,t,o,i]}class R extends g{constructor(e){super(),c(this,e,Q,P,d,{elem_id:0,variant:1,parent:3,style:2})}}var k=R;const z=["static"];export{k as Component,z as modes};
