div.svelte-n6dnoo>*:not(.absolute){border-radius:0}div.svelte-n6dnoo>*:first-child{border-top-left-radius:.5rem;border-top-right-radius:.5rem}div.svelte-n6dnoo>*:last-child{border-bottom-left-radius:.5rem;border-bottom-right-radius:.5rem}div.svelte-n6dnoo>*+*:not(.absolute){border-top-width:0px}
