import{S as p,i as h,s as k,f as b,b as _,c as v,d as B,P as T,Q as w,R as C,v as u,w as c,e as S,k as D,y as E,z as F,A as I,T as K,K as M,ab as N,a3 as P,U as q,q as Q,u as R,x as U,F as j}from"./index.b05fc228.js";import{a as G}from"./Tabs.0bad1099.js";function g(n){let t,a,e;const l=n[6].default,s=q(l,n,n[5],null);return{c(){t=b("div"),a=b("div"),s&&s.c(),_(a,"class","flex flex-col gr-gap gr-form-gap relative col overflow-auto flex-1"),_(t,"id",n[0]),_(t,"class","tabitem p-2 border-2 border-t-0 border-gray-200 relative flex")},m(i,o){v(i,t,o),B(t,a),s&&s.m(a,null),e=!0},p(i,o){s&&s.p&&(!e||o&32)&&T(s,l,i,i[5],e?C(l,i[5],o,null):w(i[5]),null),(!e||o&1)&&_(t,"id",i[0])},i(i){e||(u(s,i),e=!0)},o(i){c(s,i),e=!1},d(i){i&&S(t),s&&s.d(i)}}}function H(n){let t,a,e=n[1]===n[2]&&g(n);return{c(){e&&e.c(),t=D()},m(l,s){e&&e.m(l,s),v(l,t,s),a=!0},p(l,[s]){l[1]===l[2]?e?(e.p(l,s),s&2&&u(e,1)):(e=g(l),e.c(),u(e,1),e.m(t.parentNode,t)):e&&(E(),c(e,1,1,()=>{e=null}),F())},i(l){a||(u(e),a=!0)},o(l){c(e),a=!1},d(l){e&&e.d(l),l&&S(t)}}}function J(n,t,a){let e,{$$slots:l={},$$scope:s}=t,{elem_id:i=""}=t,{name:o}=t;const r=I(),m={},{register_tab:A,unregister_tab:z,selected_tab:d}=K(G);return M(n,d,f=>a(1,e=f)),A({name:o,id:m}),N(()=>()=>z({name:o,id:m})),n.$$set=f=>{"elem_id"in f&&a(0,i=f.elem_id),"name"in f&&a(4,o=f.name),"$$scope"in f&&a(5,s=f.$$scope)},n.$$.update=()=>{n.$$.dirty&2&&e===m&&P().then(()=>r("select"))},[i,e,m,d,o,s,l]}class L extends p{constructor(t){super(),h(this,t,J,H,k,{elem_id:0,name:4})}}function O(n){let t;const a=n[2].default,e=q(a,n,n[4],null);return{c(){e&&e.c()},m(l,s){e&&e.m(l,s),t=!0},p(l,s){e&&e.p&&(!t||s&16)&&T(e,a,l,l[4],t?C(a,l[4],s,null):w(l[4]),null)},i(l){t||(u(e,l),t=!0)},o(l){c(e,l),t=!1},d(l){e&&e.d(l)}}}function V(n){let t,a;return t=new L({props:{elem_id:n[0],name:n[1],$$slots:{default:[O]},$$scope:{ctx:n}}}),t.$on("select",n[3]),{c(){Q(t.$$.fragment)},m(e,l){R(t,e,l),a=!0},p(e,[l]){const s={};l&1&&(s.elem_id=e[0]),l&2&&(s.name=e[1]),l&16&&(s.$$scope={dirty:l,ctx:e}),t.$set(s)},i(e){a||(u(t.$$.fragment,e),a=!0)},o(e){c(t.$$.fragment,e),a=!1},d(e){U(t,e)}}}function W(n,t,a){let{$$slots:e={},$$scope:l}=t,{elem_id:s=""}=t,{label:i}=t;function o(r){j.call(this,n,r)}return n.$$set=r=>{"elem_id"in r&&a(0,s=r.elem_id),"label"in r&&a(1,i=r.label),"$$scope"in r&&a(4,l=r.$$scope)},[s,i,e,o,l]}class X extends p{constructor(t){super(),h(this,t,W,V,k,{elem_id:0,label:1})}}var y=X;const $=["static"];export{y as Component,$ as modes};
