import{S as m,i as _,s as d,f as u,q as g,m as h,h as w,b,t as c,c as p,d as f,u as x,j as y,v as I,w as v,e as k,x as q}from"./index.b05fc228.js";function B(l){let e,s,n,r,o,t;return n=new l[1]({}),{c(){e=u("div"),s=u("span"),g(n.$$.fragment),r=h(),o=w(l[0]),b(s,"class","mr-2 h-[12px] w-[12px] opacity-80"),b(e,"class","absolute left-0 top-0 py-1 px-2 rounded-br-lg shadow-sm text-xs text-gray-500 flex items-center pointer-events-none bg-white z-20 border-b border-r border-gray-100 dark:bg-gray-900"),c(e,"h-0",!l[2]),c(e,"sr-only",!l[2])},m(a,i){p(a,e,i),f(e,s),x(n,s,null),f(e,r),f(e,o),t=!0},p(a,[i]){(!t||i&1)&&y(o,a[0]),i&4&&c(e,"h-0",!a[2]),i&4&&c(e,"sr-only",!a[2])},i(a){t||(I(n.$$.fragment,a),t=!0)},o(a){v(n.$$.fragment,a),t=!1},d(a){a&&k(e),q(n)}}}function S(l,e,s){let{label:n=null}=e,{Icon:r}=e,{show_label:o=!0}=e;return l.$$set=t=>{"label"in t&&s(0,n=t.label),"Icon"in t&&s(1,r=t.Icon),"show_label"in t&&s(2,o=t.show_label)},[n,r,o]}class z extends m{constructor(e){super(),_(this,e,S,B,d,{label:0,Icon:1,show_label:2})}}export{z as B};
